syntax = "proto3";

package mix.api.v3;

import "google/api/annotations.proto";
import "google/protobuf/timestamp.proto";

/** 
 * Application Configuration Service API
 */
service AppConfigs {
	// Returns the list of application configurations that correspond to a set of parameters.
    rpc ListAppConfigs (ListAppConfigsRequest) returns (ListAppConfigsResponse) {
        option (google.api.http) = {
            get : "/api/v3/appconfigs"
            body: "request"
        };
    }
	// Downloads artifacts.
    rpc DownloadAppConfigArtifacts (DownloadAppConfigArtifactsRequest) returns (stream DownloadAppConfigArtifactsResponse) {
        option (google.api.http) = {
            get : "/api/v3/appconfig/artifact"
            body: "request"
        };
    }
}


/**
 * Request object used by the ListAppConfigs method. It returns the list of application configurations that correspond 
 * to a set of parameters. You must pass at least one of the query parameters.
 */
message ListAppConfigsRequest {
    string namespace = 1; // Namespace; for example, 'jane.smith@company.com'.
    string region_name = 2; // Name of the region; for example, 'Azure East US'.
    string environment_name = 3; // Name of the environment; for example, 'Sandbox'.
    string app_id = 4; // ID of the application; for example, 'NMDPTRIAL_jane_smith_company_com_20191234T1456456374914'.
}

/**
 * Response object used by the ListAppConfigs method. It contains one of more AppConfig objects.
 */
message ListAppConfigsResponse {
    repeated AppConfig app_configs = 1; // Repeated. List of corresponding application configurations.
}


/**
 *Type of resource.
 */
enum ModelType {
    UNDEFINED = 0; // Undefined.
    ASR = 1; // Mix.asr DLM.
    NLU = 2; // Mix.nlu model.
    DIALOG = 3; // Mix.dialog application.
}

/**
 * Object specifying a Mix.asr, Mix.nlu, or Mix.dialog resource.
 */
message Model {
    ModelType type = 1; // Type of resource. 
    string language = 2; // Language code for the resource.
    string nuance_datapack_version = 3; // Nuance Data Pack (NDP) version.
    string qnlp_datapack_version = 4; // Quick NLP/NLU data pack version. 
    google.protobuf.Timestamp update_time = 5; // Time the application configuration was last updated.
}

/**
 * Object containing a single application configuration.
 */
message AppConfig {
    string app_id = 1; // ID of the application.
    string tag = 2; // Context tag associated with this application configuration.
    repeated Model models = 3; // Repeated. List of Mix.asr, Mix.nlu, and Mix.dialog resources available for this app config.
    google.protobuf.Timestamp update_time = 4; // Time the application configuration was last updated. 
}

/**
 * Request object used by the DownloadAppConfigArtifacts method. It downloads the artifacts that correspond 
 * to a set of parameters. You must pass all of the query parameters.
 */
message DownloadAppConfigArtifactsRequest {
    string namespace = 1; // Namespace; for example, 'jane.smith@company.com'.
    string region_name = 2; // Name of the region; for example, 'Azure East US'.
    string environment_name = 3; // Name of the environment; for example, 'Sandbox'.
    string app_id = 4; // ID of the application; for example, 'NMDPTRIAL_jane_smith_company_com_20191234T1456456374914'.
    string tag = 5; // Context tag associated with the application configuration; for example, 'coffee_app'. 
    string language = 6; // Language code for the resource; for example, 'eng-USA'.
    ModelType model_type = 7; // Type of resource to download. 
}

/**
 * Object containing the artifact requested.
 */
message DownloadAppConfigArtifactsResponse {
    bytes chunk = 1; // Stream of artifact data. 
}

